--- /dev/null	Fri Nov 22 15:22:36 2013
+++ new/usr/src/test/zfs-tests/tests/functional/xattr/xattr_common.kshlib	Fri Nov 22 15:22:36 2013
@@ -0,0 +1,107 @@
+#
+# CDDL HEADER START
+#
+# The contents of this file are subject to the terms of the
+# Common Development and Distribution License (the "License").
+# You may not use this file except in compliance with the License.
+#
+# You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
+# or http://www.opensolaris.org/os/licensing.
+# See the License for the specific language governing permissions
+# and limitations under the License.
+#
+# When distributing Covered Code, include this CDDL HEADER in each
+# file and include the License file at usr/src/OPENSOLARIS.LICENSE.
+# If applicable, add the following below this CDDL HEADER, with the
+# fields enclosed by brackets "[]" replaced with your own identifying
+# information: Portions Copyright [yyyy] [name of copyright owner]
+#
+# CDDL HEADER END
+#
+
+#
+# Copyright 2008 Sun Microsystems, Inc.  All rights reserved.
+# Use is subject to license terms.
+#
+
+#
+# Copyright (c) 2013 by Delphix. All rights reserved.
+#
+
+. $STF_SUITE/include/libtest.shlib
+
+# a function that takes a file, then creates and verifies
+# an xattr on that file. The xattr_contents is the file
+# that should appear in the xattr namespace.
+function create_xattr { # filename xattr_name xattr_contents
+	typeset FILE=$1
+	typeset XATTR_NAME=$2
+	typeset XATTR_CONTENTS=$3
+
+	# read any empty xattr on that file
+	log_must $RUNAT $FILE $LS
+	# create the xattr
+	log_must $RUNAT $FILE $CP $XATTR_CONTENTS $XATTR_NAME
+
+	verify_xattr $FILE $XATTR_NAME $XATTR_CONTENTS
+}
+
+# a function that compares the a single xattr between two files
+# and checks to see if their contents are identical
+function compare_xattrs { # filename1 filename2 xattr_name
+	typeset FILE1=$1
+	typeset FILE2=$2
+	typeset XATTR_NAME=$3
+
+	$RUNAT $FILE1 $CAT $XATTR_NAME > /tmp/file1.$$
+	$RUNAT $FILE2 $CAT $XATTR_NAME > /tmp/file2.$$
+
+	log_must $DIFF /tmp/file1.$$ /tmp/file2.$$
+	log_must $RM /tmp/file1.$$ /tmp/file2.$$
+}
+
+function verify_xattr { # filename xattr_name xattr_contents
+	typeset FILE=$1
+	typeset XATTR_NAME=$2
+	typeset XATTR_CONTENTS=$3
+
+	# read the xattr, writing it to a temp file
+	log_must eval "$RUNAT $FILE $CAT $XATTR_NAME > /tmp/$XATTR_NAME.$$ 2>&1"
+	log_must $DIFF $XATTR_CONTENTS /tmp/$XATTR_NAME.$$
+	$RM /tmp/$XATTR_NAME.$$
+}
+
+function delete_xattr { # filename xattr_name
+        typeset FILE=$1
+        typeset XATTR_NAME=$2
+
+        # delete the xattr
+        log_must $RUNAT $FILE $RM $XATTR_NAME
+        log_mustnot eval "$RUNAT $FILE $LS $XATTR_NAME > /dev/null 2>&1"
+}
+
+# not sure about this : really this should be testing write/append
+function verify_write_xattr { # filename xattr_name
+        typeset FILE=$1
+        typeset XATTR_NAME=$2
+
+        log_must eval "$RUNAT $FILE $DD if=/etc/passwd of=$XATTR_NAME"
+        log_must eval "$RUNAT $FILE $CAT $XATTR_NAME > /tmp/$XATTR_NAME.$$ 2>&1"
+        log_must $DD if=/etc/passwd of=/tmp/passwd_dd.$$
+        log_must $DIFF /tmp/passwd_dd.$$ /tmp/$XATTR_NAME.$$
+        log_must $RM /tmp/passwd_dd.$$ /tmp/$XATTR_NAME.$$
+}
+
+# this function is to create the expected output
+function create_expected_output  { # expected_output_file  contents_of_the_output
+   typeset FILE=$1
+   shift
+   if [[ -f $FILE ]]; then
+      log_must $RM $FILE
+   fi
+
+   for line in $@
+   do
+      log_must eval "$ECHO $line >> $FILE"
+   done
+ }
